==> org.eclipse.justj.openjdk.hotspot.jre.full-11.0.24-macosx-aarch64.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fo.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fo extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "kr" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Sameindu Emirr\u00edkini dirham" },
            { "afn", "Afganistan afghani" },
            { "all", "Albania lek" },
            { "amd", "Armenia dram" },
            { "ang", "Ni\u00f0urlonds Karibia gyllin" },
            { "aoa", "Angola kwanza" },
            { "ars", "Argentina peso" },
            { "aud", "Avstralskur dollari" },
            { "awg", "Aruba florin" },
            { "azn", "Aserbadjan manat" },
            { "bam", "Bosnia-Hersegovina mark (kann vekslast)" },
            { "bbd", "Barbados dollari" },
            { "bdt", "Bangladesj taka" },
            { "bgn", "Bulgaria lev" },
            { "bhd", "Barein dinar" },
            { "bif", "Burundi frankur" },
            { "bmd", "Bermuda dollari" },
            { "bnd", "Brunei dollari" },
            { "bob", "Bolivia boliviano" },
            { "brl", "Brasilianskur real" },
            { "bsd", "Bahamaoyggjar dollari" },
            { "btn", "Butan ngultrum" },
            { "bwp", "Botsvana pula" },
            { "byn", "Hv\u00edtarussland ruble" },
            { "byr", "Hv\u00edtarussland ruble (2000\u20132016)" },
            { "bzd", "Belis dollari" },
            { "cad", "Kanada dollari" },
            { "cdf", "Kongo frankur" },
            { "chf", "sveisiskur frankur" },
            { "clp", "Kili peso" },
            { "cnh", "kinesiskur yuan (\u00far landi)" },
            { "cny", "kinesiskur yuan" },
            { "cop", "Kolombia peso" },
            { "crc", "Kosta Rika col\u00f3n" },
            { "cuc", "Kuba peso (sum kann vekslast)" },
            { "cup", "Kuba peso" },
            { "cve", "Gr\u00f8nh\u00f8vdaoyggjar escudo" },
            { "czk", "Kekkia koruna" },
            { "djf", "Djibuti frankur" },
            { "dkk", "donsk kr\u00f3na" },
            { "dop", "Dominika peso" },
            { "dzd", "Algeria dinar" },
            { "egp", "Egyptaland pund" },
            { "ern", "Eritrea nakfa" },
            { "etb", "Etiopia birr" },
            { "eur", "Evra" },
            { "fjd", "Fiji dollari" },
            { "fkp", "Falklandsoyggjar pund" },
            { "gbp", "bretsk pund" },
            { "gel", "Georgia lari" },
            { "ghs", "Gana cedi" },
            { "gip", "Gibraltar pund" },
            { "gmd", "Gambia dalasi" },
            { "gnf", "Guinea frankur" },
            { "gtq", "Guatemala quetzal" },
            { "gyd", "Gujana dollari" },
            { "hkd", "Hong Kong dollari" },
            { "hnl", "Honduras lempira" },
            { "hrk", "Kroatia kuna" },
            { "htg", "Haiti gourde" },
            { "huf", "Ungarn forint" },
            { "idr", "Indonesia rupiah" },
            { "ils", "\u00cdsrael new shekel" },
            { "inr", "indiskir rupis" },
            { "iqd", "Irak dinar" },
            { "irr", "iranskir rials" },
            { "isk", "\u00edslendsk kr\u00f3na" },
            { "jmd", "Jamaika dollari" },
            { "jod", "Jordan dinar" },
            { "jpy", "japanskur yen" },
            { "kes", "kenjanskur skillingur" },
            { "kgs", "Kirgisia som" },
            { "khr", "Kambodja riel" },
            { "kmf", "Komoroyggjar frankur" },
            { "kpw", "Nor\u00f0urkorea won" },
            { "krw", "Su\u00f0urkorea won" },
            { "kwd", "Kuvait dinar" },
            { "kyd", "Caymanoyggjar dollari" },
            { "kzt", "Kasakstan tenge" },
            { "lak", "Laos kip" },
            { "lbp", "Libanon pund" },
            { "lkr", "Sri Lanka rupi" },
            { "lrd", "Liberia dollari" },
            { "lyd", "Libya dinar" },
            { "mad", "Marokko dirham" },
            { "mdl", "Moldova leu" },
            { "mga", "Madagaskar ariary" },
            { "mkd", "Maked\u00f3nia denar" },
            { "mmk", "Myanmar (Burma) kyat" },
            { "mnt", "Mongolia tugrik" },
            { "mop", "Makao pataca" },
            { "mro", "M\u00f3ritania ouguiya (1973\u20132017)" },
            { "mru", "M\u00f3ritania ouguiya" },
            { "mur", "M\u00f3ritius rupi" },
            { "mvr", "Maldivoyggjar rufiyaa" },
            { "mwk", "Malavi kwacha" },
            { "mxn", "Meksiko peso" },
            { "myr", "Malaisia ringgit" },
            { "mzn", "Mosambik metical" },
            { "nad", "Namibia dollari" },
            { "ngn", "Nigeria naira" },
            { "nio", "Nikaragua c\u00f3rdoba" },
            { "nok", "norsk kr\u00f3na" },
            { "npr", "Nepal rupi" },
            { "nzd", "N\u00fds\u00e6land dollari" },
            { "omr", "Oman rial" },
            { "pab", "Panama balboa" },
            { "pen", "Peru sol" },
            { "pgk", "Papua N\u00fdguinea kina" },
            { "php", "Filipsoyggjar peso" },
            { "pkr", "Pakistan rupi" },
            { "pln", "P\u00f3lland zloty" },
            { "pyg", "Paraguai guarani" },
            { "qar", "Katar rial" },
            { "ron", "Rumenia leu" },
            { "rsd", "Serbia dinar" },
            { "rub", "Russland ruble" },
            { "rwf", "Ruanda frankur" },
            { "sar", "Saudiarabia riyal" },
            { "sbd", "Salomonoyggjar dollari" },
            { "scr", "Seyskelloyggjar rupi" },
            { "sdg", "Sudan pund" },
            { "sek", "svensk kr\u00f3na" },
            { "sgd", "Singapor dollari" },
            { "shp", "St. Helena pund" },
            { "sll", "Sierra Leona leone" },
            { "sos", "Somalia skillingur" },
            { "srd", "Surinam dollari" },
            { "ssp", "Su\u00f0ursudan pund" },
            { "std", "Sao Tome & Prinsipi dobra (1977\u20132017)" },
            { "stn", "Sao Tome & Prinsipi dobra" },
            { "syp", "S\u00fdria pund" },
            { "szl", "Svasiland lilangeni" },
            { "thb", "Tailand baht" },
            { "tjs", "Tadsjikistan somoni" },
            { "tmt", "Turkmenistan manat" },
            { "tnd", "Tunesia dinar" },
            { "top", "Tonga pa\u02bbanga" },
            { "try", "Turkaland liri" },
            { "ttd", "Trinidad & Tobago dollari" },
            { "twd", "Taivan new dollari" },
            { "tzs", "Tansania skillingur" },
            { "uah", "Ukraina hryvnia" },
            { "ugx", "Uganda skillingur" },
            { "usd", "US dollari" },
            { "uyu", "Uruguai peso" },
            { "uzs", "Usbekistan som" },
            { "vef", "Venesuela bol\u00edvar" },
            { "vnd", "Vjetnam dong" },
            { "vuv", "Vanuatu vatu" },
            { "wst", "Samoa tala" },
            { "xaf", "Mi\u00f0afrika CFA frankur" },
            { "xag", "unse s\u00f8lv" },
            { "xau", "unse guld" },
            { "xcd", "Eystur Karibia dollari" },
            { "xof", "Vesturafrika CFA frankur" },
            { "xpd", "unse palladium" },
            { "xpf", "CFP frankur" },
            { "xpt", "unse platin" },
            { "xxx", "\u00f3kent gjaldoyra" },
            { "yer", "Jemen rial" },
            { "zar", "Su\u00f0urafrika rand" },
            { "zmw", "Sambia kwacha" },
        };
        return data;
    }
}

==> org.eclipse.justj.openjdk.hotspot.jre.full-17.0.1-macosx-aarch64.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_fo.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_fo extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "kr" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "THB" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Sameindu Emirr\u00edkini dirham" },
            { "afn", "Afganistan afghani" },
            { "all", "Albania lek" },
            { "amd", "Armenia dram" },
            { "ang", "Ni\u00f0urlonds Karibia gyllin" },
            { "aoa", "Angola kwanza" },
            { "ars", "Argentina peso" },
            { "aud", "Avstralskur dollari" },
            { "awg", "Aruba florin" },
            { "azn", "Aserbadjan manat" },
            { "bam", "Bosnia-Hersegovina mark (kann vekslast)" },
            { "bbd", "Barbados dollari" },
            { "bdt", "Bangladesj taka" },
            { "bgn", "Bulgarskur Lev" },
            { "bhd", "Barein dinar" },
            { "bif", "Burundi frankur" },
            { "bmd", "Bermuda dollari" },
            { "bnd", "Brunei dollari" },
            { "bob", "Bolivia boliviano" },
            { "brl", "Brasilianskur real" },
            { "bsd", "Bahamaoyggjar dollari" },
            { "btn", "Butan ngultrum" },
            { "bwp", "Botsvana pula" },
            { "byn", "Hv\u00edtarussiskur Ruble" },
            { "byr", "Hv\u00edtarussland ruble (2000\u20132016)" },
            { "bzd", "Belis dollari" },
            { "cad", "Kanadiskur dollari" },
            { "cdf", "Kongo frankur" },
            { "chf", "sveisiskur frankur" },
            { "clp", "Kili peso" },
            { "cnh", "kinesiskur yuan (\u00far landi)" },
            { "cny", "kinesiskur yuan" },
            { "cop", "Kolombia peso" },
            { "crc", "Kosta Rika col\u00f3n" },
            { "cuc", "Kuba peso (sum kann vekslast)" },
            { "cup", "Kuba peso" },
            { "cve", "Gr\u00f8nh\u00f8vdaoyggjar escudo" },
            { "czk", "Kekkiskt Koruna" },
            { "djf", "Djibuti frankur" },
            { "dkk", "donsk kr\u00f3na" },
            { "dop", "Dominika peso" },
            { "dzd", "Algeria dinar" },
            { "egp", "Egyptaland pund" },
            { "ern", "Eritrea nakfa" },
            { "etb", "Etiopia birr" },
            { "eur", "Evra" },
            { "fjd", "Fiji dollari" },
            { "fkp", "Falklandsoyggjar pund" },
            { "gbp", "bretsk pund" },
            { "gel", "Georgia lari" },
            { "ghs", "Gana cedi" },
            { "gip", "Gibraltar pund" },
            { "gmd", "Gambia dalasi" },
            { "gnf", "Guinea frankur" },
            { "gtq", "Guatemala quetzal" },
            { "gyd", "Gujana dollari" },
            { "hkd", "Hong Kong dollari" },
            { "hnl", "Honduras lempira" },
            { "hrk", "Kroatia kuna" },
            { "htg", "Haiti gourde" },
            { "huf", "Ungarskur Forintur" },
            { "idr", "Indonesia rupiah" },
            { "ils", "\u00cdsrael new shekel" },
            { "inr", "indiskir rupis" },
            { "iqd", "Irak dinar" },
            { "irr", "iranskir rials" },
            { "isk", "\u00edslendsk kr\u00f3na" },
            { "jmd", "Jamaika dollari" },
            { "jod", "Jordan dinar" },
            { "jpy", "japanskur yen" },
            { "kes", "kenjanskur skillingur" },
            { "kgs", "Kirgisia som" },
            { "khr", "Kambodja riel" },
            { "kmf", "Komoroyggjar frankur" },
            { "kpw", "Nor\u00f0urkorea won" },
            { "krw", "Su\u00f0urkorea won" },
            { "kwd", "Kuvait dinar" },
            { "kyd", "Caymanoyggjar dollari" },
            { "kzt", "Kasakstan tenge" },
            { "lak", "Laos kip" },
            { "lbp", "Libanon pund" },
            { "lkr", "Sri Lanka rupi" },
            { "lrd", "Liberia dollari" },
            { "lyd", "Libya dinar" },
            { "mad", "Marokko dirham" },
            { "mdl", "Moldovanskur Leu" },
            { "mga", "Madagaskar ariary" },
            { "mkd", "Maked\u00f3nia denar" },
            { "mmk", "Myanmar (Burma) kyat" },
            { "mnt", "Mongolia tugrik" },
            { "mop", "Makao pataca" },
            { "mro", "M\u00f3ritania ouguiya (1973\u20132017)" },
            { "mru", "M\u00f3ritania ouguiya" },
            { "mur", "M\u00f3ritius rupi" },
            { "mvr", "Maldivoyggjar rufiyaa" },
            { "mwk", "Malavi kwacha" },
            { "mxn", "Meksiko peso" },
            { "myr", "Malaisia ringgit" },
            { "mzn", "Mosambik metical" },
            { "nad", "Namibia dollari" },
            { "ngn", "Nigeria naira" },
            { "nio", "Nikaragua c\u00f3rdoba" },
            { "nok", "norsk kr\u00f3na" },
            { "npr", "Nepal rupi" },
            { "nzd", "N\u00fds\u00e6land dollari" },
            { "omr", "Oman rial" },
            { "pab", "Panama balboa" },
            { "pen", "Peru sol" },
            { "pgk", "Papua N\u00fdguinea kina" },
            { "php", "Filipsoyggjar peso" },
            { "pkr", "Pakistan rupi" },
            { "pln", "P\u00f3lskur Zloty" },
            { "pyg", "Paraguai guarani" },
            { "qar", "Katar rial" },
            { "ron", "Rumenia leu" },
            { "rsd", "Serbia dinar" },
            { "rub", "Russland ruble" },
            { "rwf", "Ruanda frankur" },
            { "sar", "Saudiarabia riyal" },
            { "sbd", "Salomonoyggjar dollari" },
            { "scr", "Seyskelloyggjar rupi" },
            { "sdg", "Sudan pund" },
            { "sek", "svensk kr\u00f3na" },
            { "sgd", "Singapor dollari" },
            { "shp", "St. Helena pund" },
            { "sll", "Sierra Leona leone" },
            { "sos", "Somalia skillingur" },
            { "srd", "Surinam dollari" },
            { "ssp", "Su\u00f0ursudan pund" },
            { "std", "Sao Tome & Prinsipi dobra (1977\u20132017)" },
            { "stn", "Sao Tome & Prinsipi dobra" },
            { "syp", "S\u00fdria pund" },
            { "szl", "Svasiland lilangeni" },
            { "thb", "Tailand baht" },
            { "tjs", "Tadsjikistan somoni" },
            { "tmt", "Turkmenistan manat" },
            { "tnd", "Tunesia dinar" },
            { "top", "Tonga pa\u02bbanga" },
            { "try", "Turkaland liri" },
            { "ttd", "Trinidad & Tobago dollari" },
            { "twd", "Taivan new dollari" },
            { "tzs", "Tansania skillingur" },
            { "uah", "Ukraina hryvnia" },
            { "ugx", "Uganda skillingur" },
            { "usd", "US dollari" },
            { "uyu", "Uruguai peso" },
            { "uzs", "Usbekistan som" },
            { "vef", "Venesuela bol\u00edvar (2008\u20132018)" },
            { "ves", "Venesuela bol\u00edvar" },
            { "vnd", "Vjetnam dong" },
            { "vuv", "Vanuatu vatu" },
            { "wst", "Samoa tala" },
            { "xaf", "Mi\u00f0afrika CFA frankur" },
            { "xag", "unse s\u00f8lv" },
            { "xau", "unse guld" },
            { "xcd", "Eystur Karibia dollari" },
            { "xof", "Vesturafrika CFA frankur" },
            { "xpd", "unse palladium" },
            { "xpf", "CFP frankur" },
            { "xpt", "unse platin" },
            { "xxx", "\u00f3kent gjaldoyra" },
            { "yer", "Jemen rial" },
            { "zar", "Su\u00f0urafrika rand" },
            { "zmw", "Sambia kwacha" },
        };
        return data;
    }
}
